@@ -1,8 +1,5 @@
-import json
 from typing import Dict
 
-import yaml
-
 import spyctl.api as api
 import spyctl.cli as cli
 import spyctl.config.configs as cfg
