@@ -189,16 +189,20 @@ MACHINES_FIELD = "machines"
 DEFAULT_API_URL = "https://api.spyderbat.com"
 
 # Response Actions
-ACTION_KILL_POD = "kill-pod"
-ACTION_KILL_PROC = "kill-process"
-ACTION_KILL_PROC_GRP = "kill-process-group"
+ACTION_KILL_POD = "agentKillPod"
+ACTION_KILL_PROC = "agentKillProcess"
+ACTION_KILL_PROC_GRP = "agentKillProcessGroup"
 ACTION_WEBHOOK = "webhook"
+ACTION_MAKE_REDFLAG = "makeRedFlag"
+ACTION_MAKE_OPSFLAG = "makeOpsFlag"
 ALLOWED_TEMPLATES = {"json", "yaml", "slack"}
 ALLOWED_ACTIONS = {
     ACTION_WEBHOOK,
     ACTION_KILL_POD,
     ACTION_KILL_PROC,
     ACTION_KILL_PROC_GRP,
+    ACTION_MAKE_REDFLAG,
+    ACTION_MAKE_OPSFLAG,
 }
 RESPONSE_FIELD = "response"
 RESP_DEFAULT_FIELD = "default"
@@ -207,6 +211,15 @@ RESP_ACTION_NAME_FIELD = "actionName"
 RESP_URL_FIELD = "url"
 RESP_TEMPLATE_FIELD = "template"
 RESP_SEVERITY_FIELD = "severity"
+# makeFlag fields
+FLAG_IMPACT = "impact"
+FLAG_CONTENT = "content"
+FLAG_SEVERITY = "severity"
+FLAG_DESCRIPTION = "description"
+# webhook fields
+URL_DESTINATION_FIELD = "urlDestination"
+TEMPLATE_FIELD = "template"
+
 
 # Selectors
 CONT_SELECTOR_FIELD = "containerSelector"
@@ -227,16 +240,11 @@ CONT_ID_FIELD = "containerID"
 CGROUP_FIELD = "cgroup"
 
 SELECTOR_FIELDS = {
-    CONT_SELECTOR_FIELD: [
-        IMAGE_FIELD,
-        IMAGEID_FIELD,
-        CONT_NAME_FIELD,
-        CONT_ID_FIELD,
-    ],
-    SVC_SELECTOR_FIELD: [CGROUP_FIELD],
-    MACHINE_SELECTOR_FIELD: [],
-    NAMESPACE_SELECTOR_FIELD: [MATCH_LABELS_FIELD],
-    POD_SELECTOR_FIELD: [MATCH_LABELS_FIELD],
+    CONT_SELECTOR_FIELD,
+    SVC_SELECTOR_FIELD,
+    MACHINE_SELECTOR_FIELD,
+    NAMESPACE_SELECTOR_FIELD,
+    POD_SELECTOR_FIELD,
 }
 
 # Policies/Fingerprints
@@ -339,8 +347,9 @@ NETWORK_POLICY_TEMPLATE = {
         }
     ],
 }
+DEFAULT_ACTION_TEMPLATE = {ACTION_MAKE_REDFLAG: {FLAG_SEVERITY: S_HIGH}}
 RESPONSE_ACTION_TEMPLATE = {
-    RESP_DEFAULT_FIELD: {RESP_SEVERITY_FIELD: S_HIGH},
+    RESP_DEFAULT_FIELD: [DEFAULT_ACTION_TEMPLATE],
     RESP_ACTIONS_FIELD: [],
 }
 METADATA_TEMPLATES = {
